@@ -7,7 +7,7 @@ use Env qw( @PATH );
 use File::Spec;
 
 # ABSTRACT: Find or build GNU Make
-our $VERSION = '0.15_01'; # TRIAL VERSION
+our $VERSION = '0.03'; # VERSION
 
 
 my $in_path;
@@ -27,19 +27,6 @@ sub exe
   $class->config('gmake_called');
 }
 
-
-sub alien_helper
-{
-  return {
-    gmake => sub {
-      # return the executable name for GNU make,
-      # usually either make or gmake depending on
-      # the platform and environment
-      Alien::gmake->exe;
-    },
-  }
-}
-
 1;
 
 __END__
@@ -54,7 +41,7 @@ Alien::gmake - Find or build GNU Make
 
 =head1 VERSION
 
-version 0.15_01
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -83,15 +70,6 @@ environment when you don't.
 
 Return the "name" of GNU make.  Normally this is either C<make> or C<gmake>.
 
-=head1 HELPERS
-
-=head2 gmake
-
- %{gmake}
-
-Returns either make or gmake depending on how GNU make is called on your 
-system.
-
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
